/***
 * Excerpted from "iOS SDK Development",
 * published by The Pragmatic Bookshelf.
 * Copyrights apply to this code. It may not be used to create training material, 
 * courses, books, articles, and the like. Contact us if you are in doubt.
 * We make no guarantees that this code is fit for any purpose. 
 * Visit http://www.pragmaticprogrammer.com/titles/adios for more book information.
***/
//
//  PRPRecipesListViewController.m
//  Recipes
//
//  Created by Bill Dudney on 9/14/12.
//  Copyright (c) 2012 Pragmatic Programmers LLC. All rights reserved.
//

#import "PRPRecipesListViewController.h"
#import "PRPRecipe.h"
#import "PRPViewController.h"
#import "PRPRecipeEditorViewController.h"

@implementation PRPRecipesListViewController

//
- (void)finishedEditingRecipe:(PRPRecipe *)recipe {
  NSUInteger row = [self.dataSource indexOfRecipe:recipe];
  NSIndexPath *path = [NSIndexPath indexPathForRow:row inSection:0];
  [self.tableView insertRowsAtIndexPaths:[NSArray arrayWithObject:path]
                        withRowAnimation:UITableViewRowAnimationLeft];
}
//

#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
  return 1;
}

- (NSInteger)tableView:(UITableView *)tableView
 numberOfRowsInSection:(NSInteger)section {
  return [self.dataSource recipeCount];
}

- (UITableViewCell *)tableView:(UITableView *)tableView
         cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
  static NSString *CellIdentifier = @"Cell";
  
  UITableViewCell *cell = [tableView
                           dequeueReusableCellWithIdentifier:CellIdentifier];
  if (cell == nil) {
    cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle
                                  reuseIdentifier:CellIdentifier];
  }
  
  PRPRecipe *recipe = [self.dataSource recipeAtIndex:indexPath.row];
  cell.textLabel.text = [recipe title];
  cell.imageView.image = [recipe image];
  cell.detailTextLabel.text = [NSString stringWithFormat:@"%@ %@",
                               [recipe preparationTime],
                               NSLocalizedString(@"minutes", nil)];
  return cell;
}

- (void)tableView:(UITableView *)tableView
commitEditingStyle:(UITableViewCellEditingStyle)editingStyle
forRowAtIndexPath:(NSIndexPath *)indexPath {
  if (editingStyle == UITableViewCellEditingStyleDelete) {
    [self.dataSource deleteRecipeAtIndex:indexPath.row];
    [tableView deleteRowsAtIndexPaths:[NSArray arrayWithObject:indexPath]
                     withRowAnimation:UITableViewRowAnimationFade];
  } else if (editingStyle == UITableViewCellEditingStyleInsert) {
  }
}

#pragma mark Seque methods

- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
  if([@"presentRecipeDetail" isEqualToString:segue.identifier]) {
    NSIndexPath *index = [self.tableView indexPathForCell:sender];
    PRPRecipe *recipe = [self.dataSource recipeAtIndex:index.row];
    [[segue destinationViewController] setRecipe:recipe];
  }
  //
  if([@"addNewRecipe" isEqualToString:segue.identifier]) {
    PRPRecipe *recipe = [self.dataSource createNewRecipe];
    UIViewController *topVC = [[segue destinationViewController]
                               topViewController];
    PRPRecipeEditorViewController *editor =
    (PRPRecipeEditorViewController *)topVC;
    editor.recipeListVC = self;
    editor.recipe = recipe;
  }
  //
}

@end
